@@ -3,8 +3,13 @@
  */
 
 #include <stdio.h>
+#include <string.h>
+#if !defined(WIN32)
+# include <unistd.h>
+#endif
 #include "struct.h"
 #include "cmd.h"
+#include "cmdlog.h"
 #include "ui.h"
 
 WORD Get2bytes(BYTE *buf)
@@ -88,7 +93,7 @@ BOOL LBA2MSF(DWORD lba, BYTE *min, BYTE *sec, BYTE *frame)
 
 
 
-int SendTestUnitReady(DRIVE *drive)
+int SendTestUnitReady(CMDDRIVE *drive)
 {
 	BYTE cdb[12];
 
@@ -96,7 +101,7 @@ int SendTestUnitReady(DRIVE *drive)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendStartStop(DRIVE *drive, BYTE immed, BYTE load_eject, BYTE start_or_load)
+int SendStartStop(CMDDRIVE *drive, BYTE immed, BYTE load_eject, BYTE start_or_load)
 {
 	BYTE cdb[12];
 
@@ -107,7 +112,7 @@ int SendStartStop(DRIVE *drive, BYTE immed, BYTE load_eject, BYTE start_or_load)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendPreventAllow(DRIVE *drive, BYTE prevent)
+int SendPreventAllow(CMDDRIVE *drive, BYTE prevent)
 {
 	BYTE cdb[12];
 
@@ -117,13 +122,13 @@ int SendPreventAllow(DRIVE *drive, BYTE prevent)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendModeSense(DRIVE *drive, BYTE page_control, BYTE page_code)
+int SendModeSense(CMDDRIVE *drive, BYTE page_control, BYTE page_code)
 {
 	BYTE cdb[12];
 	WORD len;
 	int ret;
 
-	len = drive->atapi ? 8:16;
+	len = drive->cmd_type==CMDDRVCTYPE_ATAPI ? 8:16;
 
 	memset(cdb, 0, sizeof(cdb));
 	cdb[0] = CMD_MODE_SENSE10;
@@ -138,15 +143,16 @@ int SendModeSense(DRIVE *drive, BYTE page_control, BYTE page_code)
 	return SendCmd(drive, cdb, len, REQ_DATAIN);
 }
 
-int SendModeSelect(DRIVE *drive, BYTE pf)
+int SendModeSelect(CMDDRIVE *drive, BYTE pf)
 {
 	BYTE cdb[12];
 	WORD len;
 	struct _MODEPAGE_HEADER *mph;
 
-	mph = (struct _MODEPAGE_HEADER *)(drive->data_buf+(drive->atapi ? 8:16));
-	len = mph->p_len + (drive->atapi ? 8:16) + 2;
-	memset(drive->data_buf, 0, drive->atapi ? 8:16);
+	mph = (struct _MODEPAGE_HEADER *)
+		(drive->data_buf+(drive->cmd_type==CMDDRVCTYPE_ATAPI ? 8:16));
+	len = mph->p_len + (drive->cmd_type==CMDDRVCTYPE_ATAPI ? 8:16) + 2;
+	memset(drive->data_buf, 0, drive->cmd_type==CMDDRVCTYPE_ATAPI ? 8:16);
 
 	memset(cdb, 0, sizeof(cdb));
 	cdb[0] = CMD_MODE_SELECT10;
@@ -155,7 +161,7 @@ int SendModeSelect(DRIVE *drive, BYTE pf)
 	return SendCmd(drive, cdb, len, REQ_DATAOUT);
 }
 
-int SendReadToc(DRIVE *drive, WORD track_sess_num, BYTE msf, BYTE format)
+int SendReadToc(CMDDRIVE *drive, WORD track_sess_num, BYTE msf, BYTE format)
 {
 	BYTE cdb[12];
 	WORD len = 4;
@@ -178,7 +184,7 @@ int SendReadToc(DRIVE *drive, WORD track_sess_num, BYTE msf, BYTE format)
 }
 
 
-int SendReadDiscInfo(DRIVE *drive)
+int SendReadDiscInfo(CMDDRIVE *drive)
 {
 	BYTE cdb[12];
 	WORD len;
@@ -198,7 +204,7 @@ int SendReadDiscInfo(DRIVE *drive)
 }
 
 
-int SendReadTrackInfo(DRIVE *drive, WORD track_num)
+int SendReadTrackInfo(CMDDRIVE *drive, WORD track_num)
 {
 	BYTE cdb[12];
 	WORD len = sizeof(struct _TRACKINFO);
@@ -212,7 +218,7 @@ int SendReadTrackInfo(DRIVE *drive, WORD track_num)
 }
 
 
-int SendCloseTrackSession(DRIVE *drive, BYTE immed, BYTE type, WORD track_num)
+int SendCloseTrackSession(CMDDRIVE *drive, BYTE immed, BYTE type, WORD track_num)
 {
 	BYTE cdb[12];
 	
@@ -224,7 +230,7 @@ int SendCloseTrackSession(DRIVE *drive, BYTE immed, BYTE type, WORD track_num)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendReadSubchannel(DRIVE *drive, BYTE track_num, BYTE msf, BYTE subq, BYTE format)
+int SendReadSubchannel(CMDDRIVE *drive, BYTE track_num, BYTE msf, BYTE subq, BYTE format)
 {
 	BYTE cdb[12];
 	WORD len=4;
@@ -245,7 +251,7 @@ int SendReadSubchannel(DRIVE *drive, BYTE track_num, BYTE msf, BYTE subq, BYTE f
 	return SendCmd(drive, cdb, len, REQ_DATAIN);
 }
 
-int SendReadCD(DRIVE *drive, DWORD addr, DWORD len)
+int SendReadCD(CMDDRIVE *drive, DWORD addr, DWORD len)
 {
 	BYTE cdb[12];
 
@@ -257,7 +263,7 @@ int SendReadCD(DRIVE *drive, DWORD addr, DWORD len)
 	return SendCmd(drive, cdb, len*2352, REQ_DATAIN);
 }
 
-int SendReadFormatCapacities(DRIVE *drive)
+int SendReadFormatCapacities(CMDDRIVE *drive)
 {
 	BYTE cdb[12];
 	WORD len=4;
@@ -277,7 +283,7 @@ int SendReadFormatCapacities(DRIVE *drive)
 
 
 
-int SendFormatUnit(DRIVE *drive, BYTE fmtdata, BYTE cmplist, BYTE format_code, WORD len)
+int SendFormatUnit(CMDDRIVE *drive, BYTE fmtdata, BYTE cmplist, BYTE format_code, WORD len)
 {
 	BYTE cdb[12];
 
@@ -287,7 +293,7 @@ int SendFormatUnit(DRIVE *drive, BYTE fmtdata, BYTE cmplist, BYTE format_code, W
 	return SendCmd(drive, cdb, len, REQ_DATAOUT);
 }
 
-int SendSetCdSpeed(DRIVE *drive, WORD read_speed, WORD write_speed, BYTE rotctl)
+int SendSetCdSpeed(CMDDRIVE *drive, WORD read_speed, WORD write_speed, BYTE rotctl)
 {
 	BYTE cdb[12];
 
@@ -299,7 +305,7 @@ int SendSetCdSpeed(DRIVE *drive, WORD read_speed, WORD write_speed, BYTE rotctl)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendSetStreaming(DRIVE *drive)
+int SendSetStreaming(CMDDRIVE *drive)
 {
 	BYTE cdb[12];
 	WORD len = sizeof(struct _PERFORMANCEDESC);
@@ -311,7 +317,7 @@ int SendSetStreaming(DRIVE *drive)
 }
 
 
-int SendSynchronizeCache(DRIVE *drive, BYTE immed)
+int SendSynchronizeCache(CMDDRIVE *drive, BYTE immed)
 {
 	BYTE cdb[12];
 
@@ -321,7 +327,7 @@ int SendSynchronizeCache(DRIVE *drive, BYTE immed)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendReserveTrack(DRIVE *drive, DWORD size)
+int SendReserveTrack(CMDDRIVE *drive, DWORD size)
 {
 	BYTE cdb[12];
 
@@ -331,7 +337,7 @@ int SendReserveTrack(DRIVE *drive, DWORD size)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendRead10(DRIVE *drive, DWORD lba, WORD len, DWORD buflen)
+int SendRead10(CMDDRIVE *drive, DWORD lba, WORD len, DWORD buflen)
 {
 	BYTE cdb[12];
 
@@ -342,7 +348,7 @@ int SendRead10(DRIVE *drive, DWORD lba, WORD len, DWORD buflen)
 	return SendCmd(drive, cdb, buflen, REQ_DATAIN);
 }
 
-int SendWrite10(DRIVE *drive, DWORD lba, WORD len, DWORD buflen)
+int SendWrite10(CMDDRIVE *drive, DWORD lba, WORD len, DWORD buflen)
 {
 	BYTE cdb[12];
 	int ret;
@@ -361,7 +367,7 @@ int SendWrite10(DRIVE *drive, DWORD lba, WORD len, DWORD buflen)
 	return ret;
 }
 
-int SendSeek10(DRIVE *drive, DWORD lba)
+int SendSeek10(CMDDRIVE *drive, DWORD lba)
 {
 	BYTE cdb[12];
 
@@ -371,7 +377,7 @@ int SendSeek10(DRIVE *drive, DWORD lba)
 	return SendCmd(drive, cdb, 0, REQ_NODATA);
 }
 
-int SendSendCueSheet(DRIVE *drive, void *cuesheet, DWORD len)
+int SendSendCueSheet(CMDDRIVE *drive, void *cuesheet, DWORD len)
 {
 	BYTE cdb[12];
 
@@ -389,20 +395,55 @@ int SendSendCueSheet(DRIVE *drive, void *cuesheet, DWORD len)
 
 
 
-
-int OpenTray(DRIVE *drive)
+int SendLongRead12(CMDDRIVE *drive, DWORD lba, DWORD len, DWORD buflen,
+				   DWORD total_blocks)
 {
-	SendPreventAllow(drive, 0);
-	return SendStartStop(drive, 1, 1, 0);
+	BYTE cdb[12];
+
+	memset(cdb, 0, sizeof(cdb));
+	cdb[0] = CMD_READ12;
+	Set4bytes(cdb+2, lba);
+	Set4bytes(cdb+6, len);
+	return SendCmdLongRead(drive, cdb, buflen, REQ_DATAIN, total_blocks);
 }
 
-int CloseTray(DRIVE *drive)
+int SendLongReadCD(CMDDRIVE *drive, DWORD addr, DWORD len,
+				   DWORD total_blocks)
 {
-	return SendStartStop(drive, 1, 1, 1);
+	BYTE cdb[12];
+
+	memset(cdb, 0, sizeof(cdb));
+	cdb[0] = CMD_READ_CD;
+	Set4bytes(cdb+2, addr);
+	Set3bytes(cdb+6, len);
+	cdb[9] = 0xf8;
+	return SendCmdLongRead(drive, cdb, len*2352, REQ_DATAIN, total_blocks);
 }
 
 
-int GetDiscType(DRIVE *drive, int *disc_type_ret, BOOL bWaitDisc)
+
+int OpenTray(CMDDRIVE *drive)
+{
+  if(drive->type == CMDDRVTYPE_NET){
+		/* lbg[N摕ũgC͍sȂ */
+	return RET_OK;
+  }
+  
+  SendPreventAllow(drive, 0);
+  return SendStartStop(drive, 1, 1, 0);
+}
+
+int CloseTray(CMDDRIVE *drive)
+{
+  if(drive->type == CMDDRVTYPE_NET){
+		/* lbg[N摕ũgC͍sȂ */
+	return RET_OK;
+  }
+  return SendStartStop(drive, 1, 1, 1);
+}
+
+
+int GetDiscType(CMDDRIVE *drive, int *disc_type_ret, BOOL bWaitDisc)
 {
 	BYTE cdb[12];
 	int ret;
@@ -441,7 +482,7 @@ int GetDiscType(DRIVE *drive, int *disc_type_ret, BOOL bWaitDisc)
 	return ret;
 }
 
-int CheckReady(DRIVE *drive, BOOL bWaitDisc)
+int CheckReady(CMDDRIVE *drive, BOOL bWaitDisc)
 {
 	int ret;
 	BOOL bGood=FALSE;
@@ -501,7 +542,7 @@ int CheckReady(DRIVE *drive, BOOL bWaitDisc)
 	return RET_OK;
 }
 
-int BlankDisc(DRIVE *drive, BYTE type)
+int BlankDisc(CMDDRIVE *drive, BYTE type)
 {
 	BYTE cdb[12];
 	int ret;
@@ -519,7 +560,7 @@ int BlankDisc(DRIVE *drive, BYTE type)
 }
 
 
-int WaitProgress(DRIVE *drive, const char *message, BOOL meter1)
+int WaitProgress(CMDDRIVE *drive, const char *message, BOOL meter1)
 {
 	WORD indicator=0;
 	BOOL bGood=FALSE;
@@ -555,26 +596,33 @@ int WaitProgress(DRIVE *drive, const char *message, BOOL meter1)
 						UIMeter2Update((int)((indicator*100+0x7fff)/0xffff));
 				}
 			}
-			/*Sleep(100);*/
+#if defined(WIN32)
+			Sleep(100);
+#else
+			usleep(100*1000);
+#endif
 		}
 	}
 
 	return RET_OK;
 }
 
-void DispCommandError(DRIVE *drive)
+void DispCommandError(CMDDRIVE *drive)
 {
 	char buf[80];
 
-	sprintf(buf, "R}hsG[(%02Xh : %X/%02X/%02X)",
-		drive->cmdcode, SD_SENSEKEY(drive), SD_ASC(drive), SD_ASCQ(drive));
-	UIDispMessage(buf, UIDMT_ERROR);
+	if(SD_SENSEKEY(drive)!=0){
+	  sprintf(buf, "R}hsG[(%02Xh : %X/%02X/%02X)",
+			  drive->cmdcode,
+			  SD_SENSEKEY(drive), SD_ASC(drive), SD_ASCQ(drive));
+	  UIDispMessage(buf, UIDMT_ERROR);
+	}
 }
 
 /*
  * READ CD R}h SUB-Q f[^擾
  */
-int GetSubQ(DRIVE *drive, DWORD lba, DWORD len)
+int GetSubQ(CMDDRIVE *drive, DWORD lba, DWORD len)
 {
 	BYTE cdb[12];
 
@@ -586,3 +634,4 @@ int GetSubQ(DRIVE *drive, DWORD lba, DWORD len)
 	return SendCmd(drive, cdb, len*16, REQ_DATAIN);
 }
 
+
