@@ -2,9 +2,14 @@
  * Copyright (C) 2004 Kagetani Hideto
  */
 #ifndef __CMD_H__
+#define __CMD_H__
 
 #include "aspi.h"
+#include "netaccess.h"
+#include "image.h"
 #include "struct.h"
+#include "drive.h"
+
 
 // ASPI Command
 #define CMD_TEST_UNIT_READY		0x00
@@ -89,17 +94,17 @@ extern void Set4bytes(BYTE *buf, DWORD value);
 extern DWORD MSF2LBA(BYTE min, BYTE sec, BYTE frame, BOOL force_positive);
 extern BOOL LBA2MSF(DWORD lba, BYTE *min, BYTE *sec, BYTE *frame);
 
-extern int SendTestUnitReady(DRIVE *drive);
-extern int SendStartStop(DRIVE *drive, BYTE immed, BYTE load_eject, BYTE start_or_load);
-extern int SendPreventAllow(DRIVE *drive, BYTE prevent);
-extern int SendModeSense(DRIVE *drive, BYTE page_control, BYTE page_code);
+extern int SendTestUnitReady(CMDDRIVE *drive);
+extern int SendStartStop(CMDDRIVE *drive, BYTE immed, BYTE load_eject, BYTE start_or_load);
+extern int SendPreventAllow(CMDDRIVE *drive, BYTE prevent);
+extern int SendModeSense(CMDDRIVE *drive, BYTE page_control, BYTE page_code);
 /* page_control */
 #define MSPC_CURRENT	0
 #define MSPC_CHANGEABLE	1
 #define MSPC_DEFAULT	2
 #define MSPC_SAVED		3
-extern int SendModeSelect(DRIVE *drive, BYTE pf);
-extern int SendReadToc(DRIVE *drive, WORD track_sess_num, BYTE msf, BYTE format);
+extern int SendModeSelect(CMDDRIVE *drive, BYTE pf);
+extern int SendReadToc(CMDDRIVE *drive, WORD track_sess_num, BYTE msf, BYTE format);
 /* format */
 #define RTF_TOC		0
 #define RTF_SESS	1
@@ -107,38 +112,43 @@ extern int SendReadToc(DRIVE *drive, WORD track_sess_num, BYTE msf, BYTE format)
 #define RTF_PMA		3
 #define RTF_ATIP	4
 #define RTF_CDTEXT	5
-extern int SendReadDiscInfo(DRIVE *drive);
-extern int SendReadTrackInfo(DRIVE *drive, WORD track_num);
-extern int SendCloseTrackSession(DRIVE *drive, BYTE immed, BYTE type, WORD track_num);
+extern int SendReadDiscInfo(CMDDRIVE *drive);
+extern int SendReadTrackInfo(CMDDRIVE *drive, WORD track_num);
+extern int SendCloseTrackSession(CMDDRIVE *drive, BYTE immed, BYTE type, WORD track_num);
 /* type */
 #define CTST_CLOSETRACK		1
 #define CTST_CLOSESESSION	2
-extern int SendReadSubchannel(DRIVE *drive, BYTE track_num, BYTE msf, BYTE subq, BYTE format);
+extern int SendReadSubchannel(CMDDRIVE *drive, BYTE track_num, BYTE msf, BYTE subq, BYTE format);
 #define RSCF_CURRENT_POS	1
 #define RSCF_MCN			2
 #define RSCF_ISRC			3
-extern int SendReadCD(DRIVE *drive, DWORD addr, DWORD len);
-extern int SendReadFormatCapacities(DRIVE *drive);
-extern int SendFormatUnit(DRIVE *drive, BYTE fmtdata, BYTE cmplist, BYTE format_code, WORD len);
+extern int SendReadCD(CMDDRIVE *drive, DWORD addr, DWORD len);
+extern int SendReadFormatCapacities(CMDDRIVE *drive);
+extern int SendFormatUnit(CMDDRIVE *drive, BYTE fmtdata, BYTE cmplist, BYTE format_code, WORD len);
 #define FUFC_CDRW		7
 #define FUFC_OTHER		1
-extern int SendSetCdSpeed(DRIVE *drive, WORD read_speed, WORD write_speed, BYTE rotctl);
-extern int SendSetStreaming(DRIVE *drive);
-extern int SendSynchronizeCache(DRIVE *drive, BYTE immed);
-extern int SendReserveTrack(DRIVE *drive, DWORD size);
-extern int SendRead10(DRIVE *drive, DWORD lba, WORD len, DWORD buflen);
-extern int SendWrite10(DRIVE *drive, DWORD lba, WORD len, DWORD buflen);
-extern int SendSeek10(DRIVE *drive, DWORD lba);
-extern int SendSendCueSheet(DRIVE *drive, void *cuesheet, DWORD len);
+extern int SendSetCdSpeed(CMDDRIVE *drive, WORD read_speed, WORD write_speed, BYTE rotctl);
+extern int SendSetStreaming(CMDDRIVE *drive);
+extern int SendSynchronizeCache(CMDDRIVE *drive, BYTE immed);
+extern int SendReserveTrack(CMDDRIVE *drive, DWORD size);
+extern int SendRead10(CMDDRIVE *drive, DWORD lba, WORD len, DWORD buflen);
+extern int SendWrite10(CMDDRIVE *drive, DWORD lba, WORD len, DWORD buflen);
+extern int SendSeek10(CMDDRIVE *drive, DWORD lba);
+extern int SendSendCueSheet(CMDDRIVE *drive, void *cuesheet, DWORD len);
+  
+extern int SendLongRead12(CMDDRIVE *drive, DWORD lba, DWORD len, DWORD buflen,
+						  DWORD total_blocks);
+extern int SendLongReadCD(CMDDRIVE *drive, DWORD addr, DWORD len,
+						  DWORD total_blocks);
 
-extern int OpenTray(DRIVE *drive);
-extern int CloseTray(DRIVE *drive);
-extern int GetDiscType(DRIVE *drive, int *disc_type_ret, BOOL bWaitDisc);
-extern int CheckReady(DRIVE *drive, BOOL bWaitDisc);
-extern int BlankDisc(DRIVE *drive, BYTE type);
-extern int WaitProgress(DRIVE *drive, const char *message, BOOL meter1);
-extern void DispCommandError(DRIVE *drive);
-extern int GetSubQ(DRIVE *drive, DWORD lba, DWORD len);
+extern int OpenTray(CMDDRIVE *drive);
+extern int CloseTray(CMDDRIVE *drive);
+extern int GetDiscType(CMDDRIVE *drive, int *disc_type_ret, BOOL bWaitDisc);
+extern int CheckReady(CMDDRIVE *drive, BOOL bWaitDisc);
+extern int BlankDisc(CMDDRIVE *drive, BYTE type);
+extern int WaitProgress(CMDDRIVE *drive, const char *message, BOOL meter1);
+extern void DispCommandError(CMDDRIVE *drive);
+extern int GetSubQ(CMDDRIVE *drive, DWORD lba, DWORD len);
 
 
 #ifdef __cplusplus
