@@ -4,6 +4,7 @@
 #include <stdio.h>
 #include <string.h>
 #if !defined(WIN32)
+# include <stdlib.h>
 # include <pwd.h>
 # include <unistd.h>
 # include <sys/types.h>
@@ -197,7 +198,7 @@ static void SaveOption()
 #endif /* WIN32 */
 
 
-int SetOption(DRIVE *reader, DRIVE *writer, int disc_type)
+int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type)
 {
 	int ret;
 	struct _MODEPAGE05 *mp05;
@@ -230,7 +231,8 @@ int SetOption(DRIVE *reader, DRIVE *writer, int disc_type)
 				DispCommandError(writer);
 				return ret;
 			}
-			mp05 = (struct _MODEPAGE05 *)(writer->data_buf + (writer->atapi ? 8:16));
+			mp05 = (struct _MODEPAGE05 *)
+				(writer->data_buf + (writer->cmd_type==CMDDRVCTYPE_ATAPI ? 8:16));
 			if(mp05->BUFE){
 				g_Option.bufe = TRUE;
 				g_Option.flags |= OPFLG_BUFE;
@@ -243,7 +245,14 @@ int SetOption(DRIVE *reader, DRIVE *writer, int disc_type)
 	}
 
 	if(reader!=NULL && writer!=NULL){
-		if(reader->hid != writer->hid || reader->tid != writer->tid){
+		if(reader->type==CMDDRVTYPE_DRIVE && writer->type==CMDDRVTYPE_DRIVE){
+			if(reader->u.drive.hid != writer->u.drive.hid ||
+				reader->u.drive.tid != writer->u.drive.tid){
+				g_Option.on_the_fly = TRUE;
+				g_Option.flags |= OPFLG_ONTHEFLY;
+			}
+		}
+		else{
 			g_Option.on_the_fly = TRUE;
 			g_Option.flags |= OPFLG_ONTHEFLY;
 		}
