@@ -5,6 +5,7 @@
 #define __OPTION_H__
 
 #include <aspi.h>
+#include "cmd.h"
 
 typedef struct {
 	int read_speed;		/* 0 ōő呬 */
@@ -29,7 +30,7 @@ typedef struct {
 extern "C" {
 #endif
 	
-extern int SetOption(DRIVE *reader, DRIVE *writer, int disc_type);
+extern int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type);
 extern OPTIONS *GetOption();
 
 #if defined(WIN32)
