@@ -10,6 +10,7 @@
 #include "messagebox.h"
 #include "settingdlg.h"
 #include "filedlg.h"
+#include "netdlg.h"
 
 static BOOL g_bAbort=FALSE;
 static GtkWidget *g_WidgetMeter1Label=NULL;
@@ -139,3 +140,12 @@ int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix)
   ret=FileDialog(bOpen, filename, size, suffix);
   return ret==FDR_OK ? UIDMRET_OK : UIDMRET_CANCEL;
 }
+
+int UINetDialog(BOOL bServer, char *remote, int size, int *port_number)
+{
+  int ret;
+
+  ret=NetDialog(bServer, remote, size, port_number);
+  return ret==NDR_OK ? UIDMRET_OK : UIDMRET_CANCEL;
+}
+
