@@ -105,6 +105,8 @@ CEnbanFukusyaDlg::CEnbanFukusyaDlg(CWnd* pParent /*=NULL*/)
 	m_nAllWritableDrives = -1;
 	m_nReadDriveISO = -1;
 	m_nWriteDriveISO = -1;
+	m_nReadDriveNet = -1;
+	m_nWriteDriveNet = -1;
 }
 
 void CEnbanFukusyaDlg::DoDataExchange(CDataExchange* pDX)
@@ -508,6 +510,11 @@ LRESULT CEnbanFukusyaDlg::OnKickIdle(WPARAM wParam, LPARAM lParam)
 	m_CmbWriter.AddString("ISOC[Wt@C");
 	m_nWriteDriveISO = m_CmbWriter.GetCount()-1;
 
+	m_CmbReader.AddString("lbg[N");
+	m_nReadDriveNet = m_CmbReader.GetCount()-1;
+	m_CmbWriter.AddString("lbg[N");
+	m_nWriteDriveNet = m_CmbWriter.GetCount()-1;
+
 	m_bScanDone = TRUE;
 //	{
 //		MsgDlg.Disp("Q MB_YESNOCANCEL ̃eXg", NULL, MB_YESNOCANCEL|MB_ICONEXCLAMATION);
@@ -562,14 +569,11 @@ void CEnbanFukusyaDlg::OnOK()
 	}
 
 	CString csTemp;
-	UINT nMessageID;
-	UINT nMBFlags;
 	CThemeMessageDlg MsgDlg;
 	CThemeSet *pThemeClass = ((CEnbanFukusyaApp *)AfxGetApp())->GetThemeClass();
 	int ret;
-	DRIVE reader, writer, *writerp=NULL;
+	DRIVEID reader, *writerp=NULL;
 	int sel_reader, sel_writer;
-	DWORD timeout = 5*60;	/* R}h^CAEg=5 */
 	BOOL bOneDrive = FALSE;
 	int nWriter;
 	int nIndex;
@@ -584,119 +588,60 @@ void CEnbanFukusyaDlg::OnOK()
 	if(sel_writer==CB_ERR)
 		return;
 
-	if(sel_writer != m_nAllWritableDrives &&
-		sel_writer != m_nWriteDriveISO &&
-		sel_reader != m_nReadDriveISO){
-		if(m_pReaderDrives[sel_reader].hid == m_pWriterDrives[sel_writer].hid &&
-			m_pReaderDrives[sel_reader].tid == m_pWriterDrives[sel_writer].tid){
-			bOneDrive = TRUE;
-		}
-	}
-
-	// hCuڑ
-	::ZeroMemory(&reader, sizeof(DRIVE));
-	::ZeroMemory(&writer, sizeof(DRIVE));
-	ret = InitializeDrive(&reader, 0x10000, 50);
-	if(ret==RET_OK){
-		if(sel_reader != m_nReadDriveISO){
-			ret = SetAspiSetting(&reader, &m_pReaderDrives[sel_reader].hid,
-									&m_pReaderDrives[sel_reader].tid, &timeout);
-		}
-	}
-	if(ret!=RET_OK){
+	writerp = (DRIVEID *)malloc(sizeof(DRIVEID));
+	if(writerp==NULL){
 		csTemp.LoadString(IDS_DRIVEINITERROR);
 		MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
 		return;
 	}
-	if(bOneDrive){
-		::CopyMemory(&writer, &reader, sizeof(DRIVE));
-		writerp = &writer;
-		nWriter=1;
-	}
-	else{
-		if(sel_writer == m_nAllWritableDrives){
-			nWriter=0;
-			for(nIndex=0; strlen((LPCTSTR)m_pWriterDrives[nIndex].inqdata)!=0; nIndex++){
-				if(m_pReaderDrives[sel_reader].hid == m_pWriterDrives[nIndex].hid &&
-					m_pReaderDrives[sel_reader].tid == m_pWriterDrives[nIndex].tid){
-					/* ǎ摕u͖ */
-					continue;
-				}
-				writerp = (DRIVE *)realloc(writerp, (nWriter+1)*sizeof(DRIVE));
-				if(writerp==NULL){
-					FreeDrive(&reader);
-					csTemp.LoadString(IDS_DRIVEINITERROR);
-					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
-					for(nIndex=0; nIndex<nWriter; nIndex++){
-						writerp[nIndex].bufsize = 0;
-						writerp[nIndex].data_buf = NULL;
-						FreeDrive(&writerp[nIndex]);
-					}
-					free(writerp);
-					return;
-				}
-				::ZeroMemory(&writerp[nWriter], sizeof(DRIVE));
-				ret = InitializeDrive(&writerp[nWriter], 0, 50);
-				if(ret!=RET_OK){
-					FreeDrive(&reader);
-					csTemp.LoadString(IDS_DRIVEINITERROR);
-					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
-					for(nIndex=0; nIndex<nWriter; nIndex++){
-						writerp[nIndex].bufsize = 0;
-						writerp[nIndex].data_buf = NULL;
-						FreeDrive(&writerp[nIndex]);
-					}
-					free(writerp);
-					return;
-				}
-				// writer̃obt@reader̃obt@L
-				writerp[nWriter].data_buf = reader.data_buf;
-				writerp[nWriter].bufsize = reader.bufsize;
-				ret = SetAspiSetting(&writerp[nWriter], &m_pWriterDrives[nIndex].hid,
-											&m_pWriterDrives[nIndex].tid, &timeout);
-				if(ret!=RET_OK){
-					FreeDrive(&reader);
-					csTemp.LoadString(IDS_DRIVEINITERROR);
-					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
-					for(nIndex=0; nIndex<=nWriter; nIndex++){
-						writerp[nIndex].bufsize = 0;
-						writerp[nIndex].data_buf = NULL;
-						FreeDrive(&writerp[nIndex]);
-					}
-					free(writerp);
-					return;
-				}
-				nWriter++;
+
+	if(sel_writer == m_nAllWritableDrives){
+		nWriter=0;
+		for(nIndex=0; strlen((LPCTSTR)m_pWriterDrives[nIndex].inqdata)!=0; nIndex++){
+			if(m_pReaderDrives[sel_reader].hid == m_pWriterDrives[nIndex].hid &&
+				m_pReaderDrives[sel_reader].tid == m_pWriterDrives[nIndex].tid){
+				/* ǎ摕u͖ */
+				continue;
 			}
-		}
-		else{
-			ret = InitializeDrive(&writer, 0, 50);
-			if(ret!=RET_OK){
-				FreeDrive(&reader);
+			writerp = (DRIVEID *)realloc(writerp, (nWriter+1)*sizeof(DRIVEID));
+			if(writerp==NULL){
 				csTemp.LoadString(IDS_DRIVEINITERROR);
 				MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
 				return;
 			}
-			// writer̃obt@reader̃obt@L
-			writer.data_buf = reader.data_buf;
-			writer.bufsize = reader.bufsize;
-			if(sel_writer != m_nWriteDriveISO){
-				ret = SetAspiSetting(&writer, &m_pWriterDrives[sel_writer].hid,
-											&m_pWriterDrives[sel_writer].tid, &timeout);
-				if(ret!=RET_OK){
-					FreeDrive(&reader);
-					writer.bufsize = 0;
-					writer.data_buf = NULL;
-					FreeDrive(&writer);
-					csTemp.LoadString(IDS_DRIVEINITERROR);
-					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
-					return;
-				}
-			}
-			nWriter = 1;
-			writerp = &writer;
+			writerp[nWriter].hid = m_pWriterDrives[nIndex].hid;
+			writerp[nWriter].tid = m_pWriterDrives[nIndex].tid;
+			nWriter++;
 		}
 	}
+	else if(sel_writer == m_nWriteDriveISO){
+		writerp->hid = HID_VIRTUAL;
+		writerp->tid = CMDDRVTYPE_ISO;
+		nWriter=1;
+	}
+	else if(sel_writer == m_nWriteDriveNet){
+		writerp->hid = HID_VIRTUAL;
+		writerp->tid = CMDDRVTYPE_NET;
+		nWriter=1;
+	}
+	else{
+		writerp->hid = m_pWriterDrives[sel_writer].hid;
+		writerp->tid = m_pWriterDrives[sel_writer].tid;
+		nWriter=1;
+	}
+	
+	if(sel_reader == m_nReadDriveISO){
+		reader.hid = HID_VIRTUAL;
+		reader.tid = CMDDRVTYPE_ISO;
+	}
+	else if(sel_reader == m_nReadDriveNet){
+		reader.hid = HID_VIRTUAL;
+		reader.tid = CMDDRVTYPE_NET;
+	}
+	else{
+		reader.hid = m_pReaderDrives[sel_reader].hid;
+		reader.tid = m_pReaderDrives[sel_reader].tid;
+	}
 
 	UIClearAbort();
 	UISetHWND(this->m_hWnd);
@@ -708,40 +653,7 @@ void CEnbanFukusyaDlg::OnOK()
 	m_BtnOK.SetWindowText(csTemp);
 	m_BtnOK.SetFocus();
 
-	ret = CopyDisc(sel_reader==m_nReadDriveISO ? NULL : &reader,
-					sel_writer==m_nWriteDriveISO ? NULL : writerp, nWriter);
-	switch(ret){
-	case RET_ABORT:
-		nMessageID = IDS_PROCESS_ABORTED;
-		nMBFlags = MB_OK|MB_ICONINFORMATION;
-		break;
-	case RET_OK:
-		if(sel_writer==m_nWriteDriveISO){
-			nMessageID = IDS_PROCESS_SUCCESS_IMAGE;
-			nMBFlags = MB_OK|MB_ICONINFORMATION;
-		}
-		else{
-			nMessageID = IDS_PROCESS_SUCCESS;
-			nMBFlags = MB_YESNO|MB_ICONINFORMATION;
-		}
-		break;
-	default:
-		nMessageID = IDS_PROCESS_ERRSTOP;
-		nMBFlags = MB_YESNO|MB_ICONSTOP;
-	}
-	csTemp.Empty();
-	csTemp.LoadString(nMessageID);
-	ret = MsgDlg.Disp(csTemp, NULL, nMBFlags);
-	if(ret==IDYES){
-		if(nMessageID==IDS_PROCESS_ERRSTOP){
-			CreateLog(&reader, writerp, nWriter);
-		}
-		else if(nMessageID==IDS_PROCESS_SUCCESS){
-			for(nIndex=0; nIndex<nWriter; nIndex++){
-				OpenTray(&writerp[nIndex]);
-			}
-		}
-	}
+	ret = CopyDisc(&reader, writerp, nWriter);
 
 	csTemp.LoadString(IDS_COPYSTART);
 	m_BtnOK.SetWindowText(csTemp);
@@ -751,23 +663,8 @@ void CEnbanFukusyaDlg::OnOK()
 	m_CmbWriter.EnableWindow(TRUE);
 	m_bRunning=FALSE;
 
-	if(!bOneDrive){
-		for(nIndex=0; nIndex<nWriter; nIndex++){
-			// LĂobt@؂藣
-			writerp[nIndex].bufsize = 0;
-			writerp[nIndex].data_buf = NULL;
-		}
-	}
-	// hCuڑ
-	FreeDrive(&reader);
-	if(!bOneDrive){
-		for(nIndex=0; nIndex<nWriter; nIndex++){
-			FreeDrive(&writerp[nIndex]);
-		}
-		if(writerp != &writer){
-			free(writerp);
-		}
-	}
+	/*  */
+	free(writerp);
 
 	SendMessage(WM_USER_UICTL, UICTL_METER2INIT, NULL);
 	SendMessage(WM_USER_UICTL, UICTL_METER1INIT, NULL);
