@@ -77,6 +77,7 @@
 #define IDB_TOWADA_DIALOGBG             189
 #define IDB_TOWADA_PROGRESSFG           190
 #define IDB_TOWADA_PROGRESSBG           191
+#define IDD_REMOTE                      192
 #define IDC_COMBO1                      1000
 #define IDC_COMBO2                      1001
 #define IDC_PROGRESS1                   1002
@@ -103,14 +104,18 @@
 #define IDC_STC_TEMPPATH                1024
 #define IDC_EDT_TEMPPATH                1025
 #define IDC_STC_INFO                    1026
+#define IDC_EDT_ADDRESS                 1027
+#define IDC_EDT_PORT                    1028
+#define IDC_STC_ADDRESS                 1029
+#define IDC_STC_PORT                    1030
 
 // Next default values for new objects
 // 
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
-#define _APS_NEXT_RESOURCE_VALUE        192
+#define _APS_NEXT_RESOURCE_VALUE        193
 #define _APS_NEXT_COMMAND_VALUE         32771
-#define _APS_NEXT_CONTROL_VALUE         1027
+#define _APS_NEXT_CONTROL_VALUE         1031
 #define _APS_NEXT_SYMED_VALUE           102
 #endif
 #endif
